
## CATO-CLI - mutation.sites.updateSecondaryAzureVSocket:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.updateSecondaryAzureVSocket) for documentation on this operation.

### Usage for mutation.sites.updateSecondaryAzureVSocket:

```bash
catocli mutation sites updateSecondaryAzureVSocket -h

catocli mutation sites updateSecondaryAzureVSocket <json>

catocli mutation sites updateSecondaryAzureVSocket --json-file mutation.sites.updateSecondaryAzureVSocket.json

catocli mutation sites updateSecondaryAzureVSocket '{"updateSecondaryAzureVSocketInput":{"floatingIp":"example_value","id":"id","interfaceIp":"example_value"}}'

catocli mutation sites updateSecondaryAzureVSocket '{
    "updateSecondaryAzureVSocketInput": {
        "floatingIp": "example_value",
        "id": "id",
        "interfaceIp": "example_value"
    }
}'
```

#### Operation Arguments for mutation.sites.updateSecondaryAzureVSocket ####

`accountId` [ID] - (required) N/A    
`updateSecondaryAzureVSocketInput` [UpdateSecondaryAzureVSocketInput] - (required) N/A    
